# Hoşgeldin!

OpenSesame 3'te yeni gibi görünüyorsun.

Eğer OpenSesame'yi daha önce hiç kullanmadıysan, başlangıç seviyesi öğreticisini (tutorial) takip etmenizi öneririm. Bu şu an için biraz vakit alacak olsa da daha sonrasında zaman kazanmanızı sağlayacaktır.

[Aşama aşama öğretici](new:http://osdoc.cogsci.nl/3.2/tutorials/beginner){: .important-button}

OpenSesame'yi daha önce kullandıysanız, OpenSesame 3 versiyonunda yeni neler olduğuna bakmanızı öneriyorum (Şu anki versiyon 3.2). Endişelenmeyin: daha önceki sürümlerde kullandığınız deneyler OpenSesame'nin bu versiyonunda da çalışacaktır. Aynı zamanda program sadece daha kolaylaştı.

[OpenSesame 3'teki yenilikler](new:http://osdoc.cogsci.nl/3.2/important-changes-3){: .button}

Her zaman destek forumunda sorular sorabileceğinizi unutmayın:

[Destek forumu](new:http://forum.cogsci.nl/){: .button}

Ya da:

[Bu mesajı sonsuza kadar yoksay](opensesame://event.os3n_dismiss_startup){: .dismiss-button}
